@@ -11,6 +11,8 @@ __docformat__ = "restructuredtext en"
 from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
+from cubicweb import tags
+from cubicweb.web.component import Link
 from cubicweb.web.views import basecomponents
 from cubicweb.uilib import js
 
@@ -93,13 +95,40 @@ class BSAuthenticatedUserStatus(basecomponents.AuthenticatedUserStatus):
             html.append(self.divider_html)
         for action in actions.get("siteactions", ()):
             self.render_actions(html.append, action)
-        ddb = AUSDropDownBox(self._cw.user.login, "\n".join(html), klass="icon-user")
+        title = self.generate_initial_from_user(self._cw.user)
+        ddb = AUSDropDownBox(title, "\n".join(html))
         ddb.render(w=w)
 
+    def generate_initial_from_user(self, user):
+        if user.firstname and user.firstname.strip() \
+           and user.surname and user.surname.strip():
+            return user.firstname[0].upper() + user.surname[0].upper()
+
+        return user.login[:2].upper()
+
     def render_actions(self, w, action):
-        w("<li>")
         self.action_link(action).render(w=w)
-        w("</li>")
+
+    def action_link(self, action):
+        kwargs = {}
+        if action.title == "logout":
+            kwargs["icon"] = "logout"
+        return self.link(self._cw._(action.title), action.url(), **kwargs)
+
+    def link(self, title, url, **kwargs):
+        kwargs["klass"] = "nj-list-group__item"
+        if self._cw.selected(url):
+            kwargs["klass"] += " active"
+        return FDSLink(url, title, **kwargs)
+
+
+class FDSLink(Link):
+
+    def render(self, w):
+        label = self.label
+        if "icon" in self.attrs:
+            label = f"<i class='material-icons mr-1'>{self.attrs['icon']}</i>{self.label}"
+        w(f"<a href='{self.href}' class='{self.attrs.get('klass', '')}'>{label}</a>")
 
 
 class AUSDropDownBox(utils.DropDownBox):
