@@ -17,15 +17,15 @@ from cubicweb.web import formfields
 def render_subfield(self, form, field, renderer):
     data = UStringIO()  # XXX add support for tracewrites
     w = data.write
-    w(u'<div class="row">')
+    w('<div class="row">')
     w(renderer.render_label(form, field))
-    w(u'<div class="col-md-9">')
+    w('<div class="col-md-9">')
     w(field.render(form, renderer))
-    w(u'</div>')
-    w(u'</div>')
-    w(u'<div class="row">')
-    w(u'<div class="col-md-offset-3 col-md-9">')
+    w("</div>")
+    w("</div>")
+    w('<div class="row">')
+    w('<div class="col-md-offset-3 col-md-9">')
     w(renderer.render_help(form, field))
-    w(u'</div>')
-    w(u'</div>')
+    w("</div>")
+    w("</div>")
     return data.getvalue()
