@@ -22,6 +22,6 @@ from cubicweb.web.views.forms import FieldsForm
 from cubicweb.web.views.autoform import AutomaticEntityForm
 
 # Forms
-FieldsForm.needs_js += ('cubes.bootstrap.edition.js',)
+FieldsForm.needs_js += ("cubes.bootstrap.edition.js",)
 FieldsForm.needs_css = ()
-FieldsForm.cssclass = AutomaticEntityForm.cssclass = 'form-horizontal'
+FieldsForm.cssclass = AutomaticEntityForm.cssclass = "form-horizontal"
