@@ -12,7 +12,7 @@ from logilab.common.decorators import monkeypatch
 
 from cubicweb.web.views import tableview
 
-tableview.TableLayout.cssclass = 'listing table table-bordered table-condensed'
+tableview.TableLayout.cssclass = "listing table table-bordered table-condensed"
 
 
 _row_attributes = tableview.TableLayout.row_attributes
@@ -21,6 +21,6 @@ _row_attributes = tableview.TableLayout.row_attributes
 @monkeypatch(tableview.TableLayout)
 def row_attributes(self, rownum):
     attrs = _row_attributes(self, rownum)
-    del attrs['onmouseover']
-    del attrs['onmouseout']
+    del attrs["onmouseover"]
+    del attrs["onmouseout"]
     return attrs
