@@ -16,10 +16,9 @@ else:
     @monkeypatch(SimilarityBox)
     def render_body(self, w):
         # bs customization begins
-        self._cw.view('list', self.cw_rset, w=w, klass='list-unstyled')
+        self._cw.view("list", self.cw_rset, w=w, klass="list-unstyled")
         # bs customization ends
-        rql = self.rql % '' % {'x': self.entity.eid}
-        title = self._cw._('entities similar to %s') % self.entity.dc_title()
-        url = self._cw.build_url('view', rql=rql,
-                                 vtitle=title)
-        w(u'<div>[%s]</div>' % tags.a(self._cw._('see all'), href=url))
+        rql = self.rql % "" % {"x": self.entity.eid}
+        title = self._cw._("entities similar to %s") % self.entity.dc_title()
+        url = self._cw.build_url("view", rql=rql, vtitle=title)
+        w("<div>[%s]</div>" % tags.a(self._cw._("see all"), href=url))
